==> boo-0.7.8.2559-src.zip: tests/BooCompiler.Tests/CallablesIntegrationTestFixture.cs <==
namespace BooCompiler.Tests	
{
	using NUnit.Framework;

	[TestFixture]
	public class CallablesIntegrationTestFixture : AbstractCompilerTestCase
	{
	
		[Test]
		public void byref_1()
		{
			RunCompilerTestCase(@"byref-1.boo");
		}
		
		[Test]
		public void byref_10()
		{
			RunCompilerTestCase(@"byref-10.boo");
		}
		
		[Test]
		public void byref_11()
		{
			RunCompilerTestCase(@"byref-11.boo");
		}
		
		[Test]
		public void byref_12()
		{
			RunCompilerTestCase(@"byref-12.boo");
		}
		
		[Test]
		public void byref_13()
		{
			RunCompilerTestCase(@"byref-13.boo");
		}
		
		[Test]
		public void byref_14()
		{
			RunCompilerTestCase(@"byref-14.boo");
		}
		
		[Test]
		public void byref_2()
		{
			RunCompilerTestCase(@"byref-2.boo");
		}
		
		[Test]
		public void byref_3()
		{
			RunCompilerTestCase(@"byref-3.boo");
		}
		
		[Test]
		public void byref_4()
		{
			RunCompilerTestCase(@"byref-4.boo");
		}
		
		[Test]
		public void byref_5()
		{
			RunCompilerTestCase(@"byref-5.boo");
		}
		
		[Test]
		public void byref_6()
		{
			RunCompilerTestCase(@"byref-6.boo");
		}
		
		[Test]
		public void byref_7()
		{
			RunCompilerTestCase(@"byref-7.boo");
		}
		
		[Test]
		public void byref_8()
		{
			RunCompilerTestCase(@"byref-8.boo");
		}
		
		[Test]
		public void byref_9()
		{
			RunCompilerTestCase(@"byref-9.boo");
		}
		
		[Test]
		public void callables_1()
		{
			RunCompilerTestCase(@"callables-1.boo");
		}
		
		[Test]
		public void callables_10()
		{
			RunCompilerTestCase(@"callables-10.boo");
		}
		
		[Test]
		public void callables_11()
		{
			RunCompilerTestCase(@"callables-11.boo");
		}
		
		[Test]
		public void callables_12()
		{
			RunCompilerTestCase(@"callables-12.boo");
		}
		
		[Test]
		public void callables_13()
		{
			RunCompilerTestCase(@"callables-13.boo");
		}
		
		[Test]
		public void callables_14()
		{
			RunCompilerTestCase(@"callables-14.boo");
		}
		
		[Test]
		public void callables_15()
		{
			RunCompilerTestCase(@"callables-15.boo");
		}
		
		[Test]
		public void callables_16()
		{
			RunCompilerTestCase(@"callables-16.boo");
		}
		
		[Test]
		public void callables_17()
		{
			RunCompilerTestCase(@"callables-17.boo");
		}
		
		[Test]
		public void callables_18()
		{
			RunCompilerTestCase(@"callables-18.boo");
		}
		
		[Test]
		public void callables_19()
		{
			RunCompilerTestCase(@"callables-19.boo");
		}
		
		[Test]
		public void callables_2()
		{
			RunCompilerTestCase(@"callables-2.boo");
		}
		
		[Test]
		public void callables_20()
		{
			RunCompilerTestCase(@"callables-20.boo");
		}
		
		[Test]
		public void callables_21()
		{
			RunCompilerTestCase(@"callables-21.boo");
		}
		
		[Test]
		public void callables_22()
		{
			RunCompilerTestCase(@"callables-22.boo");
		}
		
		[Test]
		public void callables_23()
		{
			RunCompilerTestCase(@"callables-23.boo");
		}
		
		[Test]
		public void callables_24()
		{
			RunCompilerTestCase(@"callables-24.boo");
		}
		
		[Test]
		public void callables_25()
		{
			RunCompilerTestCase(@"callables-25.boo");
		}
		
		[Test]
		public void callables_26()
		{
			RunCompilerTestCase(@"callables-26.boo");
		}
		
		[Test]
		public void callables_27()
		{
			RunCompilerTestCase(@"callables-27.boo");
		}
		
		[Test]
		public void callables_28()
		{
			RunCompilerTestCase(@"callables-28.boo");
		}
		
		[Test]
		public void callables_29()
		{
			RunCompilerTestCase(@"callables-29.boo");
		}
		
		[Test]
		public void callables_3()
		{
			RunCompilerTestCase(@"callables-3.boo");
		}
		
		[Test]
		public void callables_30()
		{
			RunCompilerTestCase(@"callables-30.boo");
		}
		
		[Test]
		public void callables_31()
		{
			RunCompilerTestCase(@"callables-31.boo");
		}
		
		[Test]
		public void callables_32()
		{
			RunCompilerTestCase(@"callables-32.boo");
		}
		
		[Test]
		public void callables_33()
		{
			RunCompilerTestCase(@"callables-33.boo");
		}
		
		[Test]
		public void callables_34()
		{
			RunCompilerTestCase(@"callables-34.boo");
		}
		
		[Test]
		public void callables_35()
		{
			RunCompilerTestCase(@"callables-35.boo");
		}
		
		[Test]
		public void callables_36()
		{
			RunCompilerTestCase(@"callables-36.boo");
		}
		
		[Test]
		public void callables_37()
		{
			RunCompilerTestCase(@"callables-37.boo");
		}
		
		[Test]
		public void callables_38()
		{
			RunCompilerTestCase(@"callables-38.boo");
		}
		
		[Test]
		public void callables_39()
		{
			RunCompilerTestCase(@"callables-39.boo");
		}
		
		[Test]
		public void callables_4()
		{
			RunCompilerTestCase(@"callables-4.boo");
		}
		
		[Test]
		public void callables_40()
		{
			RunCompilerTestCase(@"callables-40.boo");
		}
		
		[Test]
		public void callables_41()
		{
			RunCompilerTestCase(@"callables-41.boo");
		}
		
		[Test]
		public void callables_42()
		{
			RunCompilerTestCase(@"callables-42.boo");
		}
		
		[Test]
		public void callables_43()
		{
			RunCompilerTestCase(@"callables-43.boo");
		}
		
		[Test]
		public void callables_44()
		{
			RunCompilerTestCase(@"callables-44.boo");
		}
		
		[Test]
		public void callables_45()
		{
			RunCompilerTestCase(@"callables-45.boo");
		}
		
		[Test]
		public void callables_46()
		{
			RunCompilerTestCase(@"callables-46.boo");
		}
		
		[Test]
		public void callables_47()
		{
			RunCompilerTestCase(@"callables-47.boo");
		}
		
		[Test]
		public void callables_48()
		{
			RunCompilerTestCase(@"callables-48.boo");
		}
		
		[Test]
		public void callables_49()
		{
			RunCompilerTestCase(@"callables-49.boo");
		}
		
		[Test]
		public void callables_5()
		{
			RunCompilerTestCase(@"callables-5.boo");
		}
		
		[Test]
		public void callables_50()
		{
			RunCompilerTestCase(@"callables-50.boo");
		}
		
		[Test]
		public void callables_6()
		{
			RunCompilerTestCase(@"callables-6.boo");
		}
		
		[Test]
		public void callables_7()
		{
			RunCompilerTestCase(@"callables-7.boo");
		}
		
		[Test]
		public void callables_8()
		{
			RunCompilerTestCase(@"callables-8.boo");
		}
		
		[Test]
		public void callables_9()
		{
			RunCompilerTestCase(@"callables-9.boo");
		}
		
		[Test]
		public void delegates_1()
		{
			RunCompilerTestCase(@"delegates-1.boo");
		}
		
		[Test]
		public void delegates_10()
		{
			RunCompilerTestCase(@"delegates-10.boo");
		}
		
		[Test]
		public void delegates_11()
		{
			RunCompilerTestCase(@"delegates-11.boo");
		}
		
		[Test]
		public void delegates_12()
		{
			RunCompilerTestCase(@"delegates-12.boo");
		}
		
		[Test]
		public void delegates_13()
		{
			RunCompilerTestCase(@"delegates-13.boo");
		}
		
		[Test]
		public void delegates_14()
		{
			RunCompilerTestCase(@"delegates-14.boo");
		}
		
		[Test]
		public void delegates_15()
		{
			RunCompilerTestCase(@"delegates-15.boo");
		}
		
		[Test]
		public void delegates_16()
		{
			RunCompilerTestCase(@"delegates-16.boo");
		}
		
		[Test]
		public void delegates_17()
		{
			RunCompilerTestCase(@"delegates-17.boo");
		}
		
		[Test]
		public void delegates_18()
		{
			RunCompilerTestCase(@"delegates-18.boo");
		}
		
		[Test]
		public void delegates_2()
		{
			RunCompilerTestCase(@"delegates-2.boo");
		}
		
		[Test]
		public void delegates_3()
		{
			RunCompilerTestCase(@"delegates-3.boo");
		}
		
		[Test]
		public void delegates_4()
		{
			RunCompilerTestCase(@"delegates-4.boo");
		}
		
		[Test]
		public void delegates_5()
		{
			RunCompilerTestCase(@"delegates-5.boo");
		}
		
		[Test]
		public void delegates_6()
		{
			RunCompilerTestCase(@"delegates-6.boo");
		}
		
		[Test]
		public void delegates_7()
		{
			RunCompilerTestCase(@"delegates-7.boo");
		}
		
		[Test]
		public void delegates_8()
		{
			RunCompilerTestCase(@"delegates-8.boo");
		}
		
		[Test]
		public void delegates_9()
		{
			RunCompilerTestCase(@"delegates-9.boo");
		}
		
		[Test]
		public void method_as_macro_1()
		{
			RunCompilerTestCase(@"method-as-macro-1.boo");
		}
		
		[Test]
		public void method_invocations_1()
		{
			RunCompilerTestCase(@"method-invocations-1.boo");
		}
		
		[Test]
		public void out_1()
		{
			RunCompilerTestCase(@"out-1.boo");
		}
		
		[Test]
		public void out_2()
		{
			RunCompilerTestCase(@"out-2.boo");
		}
		
		[Test]
		public void out_3()
		{
			RunCompilerTestCase(@"out-3.boo");
		}
		
		[Test]
		public void overload_resolution_1()
		{
			RunCompilerTestCase(@"overload-resolution-1.boo");
		}
		
		[Test]
		public void params_1()
		{
			RunCompilerTestCase(@"params-1.boo");
		}
		
		[Test]
		public void params_2()
		{
			RunCompilerTestCase(@"params-2.boo");
		}
		
		[Test]
		public void params_3()
		{
			RunCompilerTestCase(@"params-3.boo");
		}
		
		[Test]
		public void params_4()
		{
			RunCompilerTestCase(@"params-4.boo");
		}
		
		[Test]
		public void params_5()
		{
			RunCompilerTestCase(@"params-5.boo");
		}
		
		[Test]
		public void params_6()
		{
			RunCompilerTestCase(@"params-6.boo");
		}
		
		[Test]
		public void params_7()
		{
			RunCompilerTestCase(@"params-7.boo");
		}
		
		
		override protected string GetRelativeTestCasesPath()
		{
			return "integration/callables";
		}
	}
}

==> boo-0.9.1.3287-src.zip: tests/BooCompiler.Tests/CallablesIntegrationTestFixture.cs <==
namespace BooCompiler.Tests
{
	using NUnit.Framework;

	[TestFixture]
	public class CallablesIntegrationTestFixture : AbstractCompilerTestCase
	{
	
		[Test]
		public void byref_1()
		{
			RunCompilerTestCase(@"byref-1.boo");
		}
		
		[Test]
		public void byref_10()
		{
			RunCompilerTestCase(@"byref-10.boo");
		}
		
		[Test]
		public void byref_11()
		{
			RunCompilerTestCase(@"byref-11.boo");
		}
		
		[Test]
		public void byref_12()
		{
			RunCompilerTestCase(@"byref-12.boo");
		}
		
		[Test]
		public void byref_13()
		{
			RunCompilerTestCase(@"byref-13.boo");
		}
		
		[Test]
		public void byref_14()
		{
			RunCompilerTestCase(@"byref-14.boo");
		}
		
		[Test]
		public void byref_2()
		{
			RunCompilerTestCase(@"byref-2.boo");
		}
		
		[Test]
		public void byref_3()
		{
			RunCompilerTestCase(@"byref-3.boo");
		}
		
		[Test]
		public void byref_4()
		{
			RunCompilerTestCase(@"byref-4.boo");
		}
		
		[Test]
		public void byref_5()
		{
			RunCompilerTestCase(@"byref-5.boo");
		}
		
		[Test]
		public void byref_6()
		{
			RunCompilerTestCase(@"byref-6.boo");
		}
		
		[Test]
		public void byref_7()
		{
			RunCompilerTestCase(@"byref-7.boo");
		}
		
		[Test]
		public void byref_8()
		{
			RunCompilerTestCase(@"byref-8.boo");
		}
		
		[Test]
		public void byref_9()
		{
			RunCompilerTestCase(@"byref-9.boo");
		}
		
		[Test]
		public void callables_1()
		{
			RunCompilerTestCase(@"callables-1.boo");
		}
		
		[Test]
		public void callables_10()
		{
			RunCompilerTestCase(@"callables-10.boo");
		}
		
		[Test]
		public void callables_11()
		{
			RunCompilerTestCase(@"callables-11.boo");
		}
		
		[Test]
		public void callables_12()
		{
			RunCompilerTestCase(@"callables-12.boo");
		}
		
		[Test]
		public void callables_13()
		{
			RunCompilerTestCase(@"callables-13.boo");
		}
		
		[Test]
		public void callables_14()
		{
			RunCompilerTestCase(@"callables-14.boo");
		}
		
		[Test]
		public void callables_15()
		{
			RunCompilerTestCase(@"callables-15.boo");
		}
		
		[Test]
		public void callables_16()
		{
			RunCompilerTestCase(@"callables-16.boo");
		}
		
		[Test]
		public void callables_17()
		{
			RunCompilerTestCase(@"callables-17.boo");
		}
		
		[Test]
		public void callables_18()
		{
			RunCompilerTestCase(@"callables-18.boo");
		}
		
		[Test]
		public void callables_19()
		{
			RunCompilerTestCase(@"callables-19.boo");
		}
		
		[Test]
		public void callables_2()
		{
			RunCompilerTestCase(@"callables-2.boo");
		}
		
		[Test]
		public void callables_20()
		{
			RunCompilerTestCase(@"callables-20.boo");
		}
		
		[Test]
		public void callables_21()
		{
			RunCompilerTestCase(@"callables-21.boo");
		}
		
		[Test]
		public void callables_22()
		{
			RunCompilerTestCase(@"callables-22.boo");
		}
		
		[Test]
		public void callables_23()
		{
			RunCompilerTestCase(@"callables-23.boo");
		}
		
		[Test]
		public void callables_24()
		{
			RunCompilerTestCase(@"callables-24.boo");
		}
		
		[Test]
		public void callables_25()
		{
			RunCompilerTestCase(@"callables-25.boo");
		}
		
		[Test]
		public void callables_26()
		{
			RunCompilerTestCase(@"callables-26.boo");
		}
		
		[Test]
		public void callables_27()
		{
			RunCompilerTestCase(@"callables-27.boo");
		}
		
		[Test]
		public void callables_28()
		{
			RunCompilerTestCase(@"callables-28.boo");
		}
		
		[Test]
		public void callables_29()
		{
			RunCompilerTestCase(@"callables-29.boo");
		}
		
		[Test]
		public void callables_3()
		{
			RunCompilerTestCase(@"callables-3.boo");
		}
		
		[Test]
		public void callables_30()
		{
			RunCompilerTestCase(@"callables-30.boo");
		}
		
		[Test]
		public void callables_31()
		{
			RunCompilerTestCase(@"callables-31.boo");
		}
		
		[Test]
		public void callables_32()
		{
			RunCompilerTestCase(@"callables-32.boo");
		}
		
		[Test]
		public void callables_33()
		{
			RunCompilerTestCase(@"callables-33.boo");
		}
		
		[Test]
		public void callables_34()
		{
			RunCompilerTestCase(@"callables-34.boo");
		}
		
		[Test]
		public void callables_35()
		{
			RunCompilerTestCase(@"callables-35.boo");
		}
		
		[Test]
		public void callables_36()
		{
			RunCompilerTestCase(@"callables-36.boo");
		}
		
		[Test]
		public void callables_37()
		{
			RunCompilerTestCase(@"callables-37.boo");
		}
		
		[Test]
		public void callables_38()
		{
			RunCompilerTestCase(@"callables-38.boo");
		}
		
		[Test]
		public void callables_39()
		{
			RunCompilerTestCase(@"callables-39.boo");
		}
		
		[Test]
		public void callables_4()
		{
			RunCompilerTestCase(@"callables-4.boo");
		}
		
		[Test]
		public void callables_40()
		{
			RunCompilerTestCase(@"callables-40.boo");
		}
		
		[Test]
		public void callables_41()
		{
			RunCompilerTestCase(@"callables-41.boo");
		}
		
		[Test]
		public void callables_42()
		{
			RunCompilerTestCase(@"callables-42.boo");
		}
		
		[Test]
		public void callables_43()
		{
			RunCompilerTestCase(@"callables-43.boo");
		}
		
		[Test]
		public void callables_44()
		{
			RunCompilerTestCase(@"callables-44.boo");
		}
		
		[Test]
		public void callables_45()
		{
			RunCompilerTestCase(@"callables-45.boo");
		}
		
		[Test]
		public void callables_46()
		{
			RunCompilerTestCase(@"callables-46.boo");
		}
		
		[Test]
		public void callables_47()
		{
			RunCompilerTestCase(@"callables-47.boo");
		}
		
		[Test]
		public void callables_48()
		{
			RunCompilerTestCase(@"callables-48.boo");
		}
		
		[Test]
		public void callables_49()
		{
			RunCompilerTestCase(@"callables-49.boo");
		}
		
		[Test]
		public void callables_5()
		{
			RunCompilerTestCase(@"callables-5.boo");
		}
		
		[Test]
		public void callables_50()
		{
			RunCompilerTestCase(@"callables-50.boo");
		}
		
		[Test]
		public void callables_6()
		{
			RunCompilerTestCase(@"callables-6.boo");
		}
		
		[Test]
		public void callables_7()
		{
			RunCompilerTestCase(@"callables-7.boo");
		}
		
		[Test]
		public void callables_8()
		{
			RunCompilerTestCase(@"callables-8.boo");
		}
		
		[Test]
		public void callables_9()
		{
			RunCompilerTestCase(@"callables-9.boo");
		}
		
		[Test]
		public void delegates_1()
		{
			RunCompilerTestCase(@"delegates-1.boo");
		}
		
		[Test]
		public void delegates_10()
		{
			RunCompilerTestCase(@"delegates-10.boo");
		}
		
		[Test]
		public void delegates_11()
		{
			RunCompilerTestCase(@"delegates-11.boo");
		}
		
		[Test]
		public void delegates_12()
		{
			RunCompilerTestCase(@"delegates-12.boo");
		}
		
		[Test]
		public void delegates_13()
		{
			RunCompilerTestCase(@"delegates-13.boo");
		}
		
		[Test]
		public void delegates_14()
		{
			RunCompilerTestCase(@"delegates-14.boo");
		}
		
		[Test]
		public void delegates_15()
		{
			RunCompilerTestCase(@"delegates-15.boo");
		}
		
		[Test]
		public void delegates_16()
		{
			RunCompilerTestCase(@"delegates-16.boo");
		}
		
		[Test]
		public void delegates_17()
		{
			RunCompilerTestCase(@"delegates-17.boo");
		}
		
		[Test]
		public void delegates_18()
		{
			RunCompilerTestCase(@"delegates-18.boo");
		}
		
		[Test]
		public void delegates_2()
		{
			RunCompilerTestCase(@"delegates-2.boo");
		}
		
		[Test]
		public void delegates_3()
		{
			RunCompilerTestCase(@"delegates-3.boo");
		}
		
		[Test]
		public void delegates_4()
		{
			RunCompilerTestCase(@"delegates-4.boo");
		}
		
		[Test]
		public void delegates_5()
		{
			RunCompilerTestCase(@"delegates-5.boo");
		}
		
		[Test]
		public void delegates_6()
		{
			RunCompilerTestCase(@"delegates-6.boo");
		}
		
		[Test]
		public void delegates_7()
		{
			RunCompilerTestCase(@"delegates-7.boo");
		}
		
		[Test]
		public void delegates_8()
		{
			RunCompilerTestCase(@"delegates-8.boo");
		}
		
		[Test]
		public void delegates_9()
		{
			RunCompilerTestCase(@"delegates-9.boo");
		}
		
		[Test]
		public void method_as_macro_1()
		{
			RunCompilerTestCase(@"method-as-macro-1.boo");
		}
		
		[Test]
		public void method_as_macro_2()
		{
			RunCompilerTestCase(@"method-as-macro-2.boo");
		}
		
		[Test]
		public void method_as_macro_3()
		{
			RunCompilerTestCase(@"method-as-macro-3.boo");
		}
		
		[Test]
		public void method_invocations_1()
		{
			RunCompilerTestCase(@"method-invocations-1.boo");
		}
		
		[Test]
		public void out_1()
		{
			RunCompilerTestCase(@"out-1.boo");
		}
		
		[Test]
		public void out_2()
		{
			RunCompilerTestCase(@"out-2.boo");
		}
		
		[Test]
		public void out_3()
		{
			RunCompilerTestCase(@"out-3.boo");
		}
		
		[Test]
		public void overload_resolution_1()
		{
			RunCompilerTestCase(@"overload-resolution-1.boo");
		}
		
		[Test]
		public void overload_resolution_2()
		{
			RunCompilerTestCase(@"overload-resolution-2.boo");
		}
		
		[Test]
		public void params_1()
		{
			RunCompilerTestCase(@"params-1.boo");
		}
		
		[Test]
		public void params_2()
		{
			RunCompilerTestCase(@"params-2.boo");
		}
		
		[Test]
		public void params_3()
		{
			RunCompilerTestCase(@"params-3.boo");
		}
		
		[Test]
		public void params_4()
		{
			RunCompilerTestCase(@"params-4.boo");
		}
		
		[Test]
		public void params_5()
		{
			RunCompilerTestCase(@"params-5.boo");
		}
		
		[Test]
		public void params_6()
		{
			RunCompilerTestCase(@"params-6.boo");
		}
		
		[Test]
		public void params_7()
		{
			RunCompilerTestCase(@"params-7.boo");
		}
		

		override protected string GetRelativeTestCasesPath()
		{
			return "integration/callables";
		}
	}
}
